signOut method
Signs out the user from the specified provider or all providers if none is specified.
Implementation
Future<Response<void>> signOut() {
throw UnimplementedError("Method signOut() is not yet implemented.");
}
Signs out the user from the specified provider or all providers if none is specified.
Future<Response<void>> signOut() {
throw UnimplementedError("Method signOut() is not yet implemented.");
}