OtpAuthenticator class
- Inheritance
-
- Object
- Authenticator
- OtpAuthenticator
Constructors
- OtpAuthenticator.email({required String token, required String code, required String email})
-
const
- OtpAuthenticator.phone({required String token, required String code, required String phone})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited