AuthKeys class

Constructors

AuthKeys({String id = "id", String timeMills = "time_mills", String biometric = "biometric", String email = "email", String loggedIn = "logged_in", String loggedInTime = "logged_in_time", String loggedOutTime = "logged_out_time", String name = "name", String password = "password", String phone = "phone", String photo = "photo", String provider = "provider", String username = "username", String verified = "verified"})
const

Properties

biometric String
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
id String
The ID key.
finalinherited
keys Iterable<String>
no setter
loggedIn String
final
loggedInTime String
final
loggedOutTime String
final
name String
final
password String
final
phone String
final
photo String
final
provider String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeMills String
The timestamp key.
finalinherited
username String
final
verified String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

key → const String