AuthMessages class

Constructors

AuthMessages({String authorization = "Authorization data not found!", String biometric = "Biometric not initialized yet!", String email = "Email isn't valid!", String error = "Something went wrong, please try again!", String otp = "OTP Code isn't valid!", String phoneNumber = "Phone number isn't valid!", String password = "Password isn't valid!", String username = "Username isn't valid!", String token = "Token isn't valid!", AuthMessage delete = const AuthMessage(done: "User deleted!", failure: "User not deleted!"), AuthMessage loggedIn = const AuthMessage(done: "User logged in!", failure: "You're not logged in!"), AuthMessage loggedOut = const AuthMessage(done: "User logged out!"), AuthMessage signInWithApple = const AuthMessage(done: "Apple sign in successful!"), AuthMessage signInWithBiometric = const AuthMessage(done: "Biometric sign in successful!", failure: "Biometric not initialized yet!"), AuthMessage signInWithEmail = const AuthMessage(done: "Sign in successful!"), AuthMessage signInWithFacebook = const AuthMessage(done: "Facebook sign in successful!"), AuthMessage signInWithGameCenter = const AuthMessage(done: "Game Center sign in successful!"), AuthMessage signInWithGithub = const AuthMessage(done: "Github sign in successful!"), AuthMessage signInWithGoogle = const AuthMessage(done: "Google sign in successful!"), AuthMessage signInWithMicrosoft = const AuthMessage(done: "Microsoft sign in successful!"), AuthMessage signInWithPhone = const AuthMessage(done: "Phone sign in successful!"), AuthMessage signInWithPlayGames = const AuthMessage(done: "Play Games sign in successful!"), AuthMessage signInWithSAML = const AuthMessage(done: "SAML sign in successful!"), AuthMessage signInWithTwitter = const AuthMessage(done: "Twitter sign in successful!"), AuthMessage signInWithUsername = const AuthMessage(done: "Sign in successful!"), AuthMessage signInWithYahoo = const AuthMessage(done: "Yahoo sign in successful!"), AuthMessage signUpWithEmail = const AuthMessage(done: "Sign up successful!"), AuthMessage signUpWithUsername = const AuthMessage(done: "Sign up successful!"), AuthMessage signOut = const AuthMessage(done: "Sign out successful!")})
const

Properties

authorization String
final
biometric String
final
delete AuthMessage
final
email String
final
error String
final
hashCode int
The hash code for this object.
no setterinherited
loggedIn AuthMessage
final
loggedOut AuthMessage
final
otp String
final
password String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signInWithApple AuthMessage
final
signInWithBiometric AuthMessage
final
signInWithEmail AuthMessage
final
signInWithFacebook AuthMessage
final
signInWithGameCenter AuthMessage
final
signInWithGithub AuthMessage
final
signInWithGoogle AuthMessage
final
signInWithMicrosoft AuthMessage
final
signInWithPhone AuthMessage
final
signInWithPlayGames AuthMessage
final
signInWithSAML AuthMessage
final
signInWithTwitter AuthMessage
final
signInWithUsername AuthMessage
final
signInWithYahoo AuthMessage
final
signOut AuthMessage
final
signUpWithEmail AuthMessage
final
signUpWithUsername AuthMessage
final
token String
final
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited