OAuthSignInAction<T extends Auth<AuthKeys>> class

Inheritance

Constructors

OAuthSignInAction({required OAuthContextCall<T> contextCall, OAuthAuthenticator? authenticator, bool storeToken = false, String? id, Object? args, bool notifiable = true})
const

Properties

args Object?
final
authenticator OAuthAuthenticator?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
notifiable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeToken bool
final

Methods

execute(BuildContext context) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited