VerifyPhoneByOtpAction<T extends Auth<AuthKeys> > class
- Inheritance
-
- Object
- AuthAction<
T> - VerifyPhoneByOtpAction
Constructors
- VerifyPhoneByOtpAction({required OtpAuthenticator authenticator})
-
const
Properties
- authenticator → OtpAuthenticator
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
BuildContext context) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited