OtpAuthenticator class

Inheritance

Constructors

OtpAuthenticator.email({required String token, required String code, required String email})
const
OtpAuthenticator.phone({required String token, required String code, required String phone})
const

Properties

code String
final
hashCode int
The hash code for this object.
no setterinherited
isEmail bool
no setter
isPhone bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
type String
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited