Credential class
Constructors
Properties
- credential → Object?
-
final
- displayName → String?
-
final
- email → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneNumber → String?
-
final
- photoURL → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smsCode → String?
-
final
- uid → String?
-
final
- verificationId → String?
-
final
Methods
-
copyWith(
{Object? credential, String? displayName, String? email, String? phoneNumber, String? photoURL, String? smsCode, String? uid, String? verificationId}) → Credential -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited