SignInAnonymouslyAction<T extends Auth<AuthKeys> > class
- Inheritance
-
- Object
- AuthAction<
T> - SignInAnonymouslyAction
Constructors
- SignInAnonymouslyAction({String? id, Object? args, bool notifiable = true, GuestAuthenticator? authenticator})
-
const
Properties
- args → Object?
-
final
- authenticator → GuestAuthenticator?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- notifiable → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
BuildContext context) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited